@@ -157,14 +157,15 @@ void KMMainWin::slotUpdateGui()
     // remove dynamically created actions before editing
     mKMMainWidget->clearFilterActions();
     mKMMainWidget->tagActionManager()->clearActions();
+    mKMMainWidget->clearPluginActions();
 
     createGUI(QStringLiteral("kmmainwin.rc"));
     applyMainWindowSettings(KMKernel::self()->config()->group("Main Window"));
 
     // plug dynamically created actions again
-    mKMMainWidget->initializeFilterActions();
+    mKMMainWidget->initializeFilterActions(false);
     mKMMainWidget->tagActionManager()->createActions();
-    mKMMainWidget->initializePluginActions();
+    //FIXME mKMMainWidget->initializePluginActions();
 }
 
 void KMMainWin::setupStatusBar()
@@ -176,7 +177,9 @@ void KMMainWin::setupStatusBar()
     statusBar()->addWidget(mMessageLabel);
 
     QTimer::singleShot(2000, KPIM::BroadcastStatus::instance(), &KPIM::BroadcastStatus::reset);
-
+#ifdef USE_DKIM_CHECKER
+    statusBar()->addPermanentWidget(mKMMainWidget->dkimWidgetInfo());
+#endif
     statusBar()->addPermanentWidget(mKMMainWidget->zoomLabelIndicator());
     statusBar()->addPermanentWidget(mKMMainWidget->vacationScriptIndicator());
     statusBar()->addPermanentWidget(mProgressBar->littleProgress());
